@@ -1,8 +1,7 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+# coding: utf-8
 #
 # Copyright 2011 Yesudeep Mangalapilly <yesudeep@gmail.com>
-# Copyright 2012 Google, Inc.
+# Copyright 2012 Google, Inc & contributors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,13 +19,11 @@
 :module: watchdog.observers.fsevents
 :synopsis: FSEvents based emitter implementation.
 :author: yesudeep@google.com (Yesudeep Mangalapilly)
+:author: contact@tiger-222.fr (Mickaël Schoentgen)
 :platforms: Mac OS X
 """
 
-from __future__ import with_statement
-
 import os
-import sys
 import threading
 import unicodedata
 import _watchdog_fsevents as _fsevents
@@ -111,7 +108,7 @@ class FSEventsEmitter(EventEmitter):
                         self.queue_event(DirModifiedEvent(os.path.dirname(event.path)))
                     # TODO: generate events for tree
 
-                elif event.is_modified or event.is_inode_meta_mod or event.is_xattr_mod:
+                elif event.is_modified or event.is_inode_meta_mod or event.is_xattr_mod :
                     cls = DirModifiedEvent if event.is_directory else FileModifiedEvent
                     self.queue_event(cls(event.path))
 
@@ -173,25 +170,8 @@ class FSEventsObserver(BaseObserver):
                               timeout=timeout)
 
     def schedule(self, event_handler, path, recursive=False):
-        # Python 2/3 compat
-        try:
-            str_class = unicode
-        except NameError:
-            str_class = str
-
         # Fix for issue #26: Trace/BPT error when given a unicode path
         # string. https://github.com/gorakhargosh/watchdog/issues#issue/26
-        if isinstance(path, str_class):
-            # path = unicode(path, 'utf-8')
+        if isinstance(path, str):
             path = unicodedata.normalize('NFC', path)
-            # We only encode the path in Python 2 for backwards compatibility.
-            # On Python 3 we want the path to stay as unicode if possible for
-            # the sake of path matching not having to be rewritten to use the
-            # bytes API instead of strings. The _watchdog_fsevent.so code for
-            # Python 3 can handle both str and bytes paths, which is why we
-            # do not HAVE to encode it with Python 3. The Python 2 code in
-            # _watchdog_fsevents.so was not changed for the sake of backwards
-            # compatibility.
-            if sys.version_info < (3,):
-                path = path.encode('utf-8')
         return BaseObserver.schedule(self, event_handler, path, recursive)
